#!/bin/sh

PATH="/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:$PATH"
MOUNT_ROOT="$1"
LOG="/dev/null"

OLD_IFS="$IFS"
IFS=':'
for PREFIX in $PATH; do
    [ "x${LVM_TOOL}" = "x" -a -x "$PREFIX/lvm" ] && LVM_TOOL="$PREFIX/lvm"
    [ "x${DMSETUP_TOOL}" = "x" -a -x "$PREFIX/dmsetup" ] && DMSETUP_TOOL="$PREFIX/dmsetup"
    [ "x${NTFS3G_TOOL}" = "x" -a -x "$PREFIX/ntfs-3g" ] && NTFS3G_TOOL="$PREFIX/ntfs-3g"
done
IFS="$OLD_IFS"

shift
for DEVICE in "$@"; do
    MOUNT=`basename "$DEVICE"`
    if [ -d "$MOUNT_ROOT/$MOUNT" ]; then
        umount "$MOUNT_ROOT/$MOUNT" >>"$LOG" 2>&1
        rmdir "$MOUNT_ROOT/$MOUNT" >>"$LOG" 2>&1
    fi

    if [ "x${LVM_TOOL}" != "x" ]; then
        IFS='
'
        VGS=`eval "$LVM_TOOL" pvs --noheadings --separator ':' -o pv_name,vg_name,lv_attr 2>/dev/null | grep -E "${DEVICE}" | sed -n '/[^:]\+:\([^:]\+\):....a.*$/s//\1/p' | sort -u`
        for VG in $VGS; do
            "$LVM_TOOL" vgchange -a n "$VG" >>"$LOG" 2>&1
        done
        IFS="$OLD_IFS"
    fi

    echo "$DEVICE" | grep -q '/dev/mapper/' >>"$LOG" 2>&1
    if [ $? -eq 0 -a "x${DMSETUP_TOOL}" != "x" ]; then
        "$DMSETUP_TOOL" remove "${DEVICE}" >>"$LOG" 2>&1
        for SUFFIX in mlog mimage_0 mimage_1 mimage_2 mimage_3 mimage_4 mimage_5 mimage_6 mimage_7 mimage_8 mimage_9; do
            [ -e "${DEVICE}_${SUFFIX}" ] && "$DMSETUP_TOOL" remove "${DEVICE}_${SUFFIX}" >>"$LOG" 2>&1
        done
    fi
done

exit 0
